/**********************************************************************************/
/*    Demo program for:								  */
/*	  Board: MSP430-G2744BP 						  */
/*    Manufacture: OLIMEX                                                   	  */
/*	  COPYRIGHT (C) 2013							  */
/*    Designed by: Engineer Penko T. Bozhkov                                      */
/*    Module Name    :  main module                                               */
/*    File   Name    :  main.c                                                    */
/*    Revision       :  1.0.0 (initial)                                           */
/*    Date           :  29.03.2013                                                */
/*    Built with IAR Embedded Workbench Version: 5.51.6                           */
/**********************************************************************************/
#include  <msp430.h>
#include  "usart.h"

#define _BIC_SR(reg) __bic_SR_register(reg)
#define _BIS_SR(reg) __bis_SR_register(reg)

#define LED_In      P1DIR &= ~0x01; // Set P1.0 to input direction
#define LED_Out     P1DIR |= 0x01;  // Set P1.0 to output direction
#define LED_On      P1OUT |= 0x01;  
#define LED_Off     P1OUT &= ~0x01; 
#define LED_Toggle  P1OUT ^= 0x01; 


/**********************************************************************************/
/*  Function name: Delay                                                          */
/*  	Parameters                                                                */
/*          Input   :  No	                                                  */
/*          Output  :  No	                                                  */
/*	Action: Simple delay							  */
/**********************************************************************************/
void Delay(volatile unsigned int delay_counter){
	while(delay_counter){delay_counter--;}
}


/**********************************************************************************/
/*  Function name: init_devices	                                                  */
/*  	Parameters                                                                */
/*          Input   :  No			     		                  */
/*          Output  :  No                                      	            	  */
/*	Action: Initialize all used MSP430F2274 peripheral devices.	  	  */
/**********************************************************************************/
void init_devices(void){
  _BIC_SR(GIE); // Disable interrupts during initialization process
  
  /********** 1.Select System Clock  ***********/
  //After a PUC, MCLK and SMCLK should be sourced from DCOCLK at ~1.1 MHz. Although:
  DCOCTL = 0;                               // Select lowest DCOx and MODx settings
  BCSCTL1 = CALBC1_1MHZ;                    // Set DCO
  DCOCTL = CALDCO_1MHZ;
  
  /********** 2.Peripherals initialization ***********/
  USART_Init();
  
  fUSART_Receive_Clear; // Clear before checking
  LED_Out;

  _BIS_SR(GIE); // Global Interrupt enabled. Do this at the END of the initialization!!!!!!!!
}


/**********************************************************************************/
/*  Function name: main	                                                  	  */
/*  	Parameters                                                                */
/*          Input   :  No			     		                  */
/*          Output  :  No                                      	            	  */
/*	Action: Call "init_devices" and "USART_Test_Menu_Begin".  		  */
/**********************************************************************************/
void  main(void){
  WDTCTL = WDTPW + WDTHOLD;       // Stop WDT
  init_devices();
  while(!fUSART_Receive_Check){}  // Wait any symbol to be received
  USART_Send_ROM_Menu_Begin();
  while(1){
    if(fUSART_Receive_Check){
      fUSART_Receive_Clear;
      LED_Toggle;
    }
  }
}




